@@ -15,7 +15,18 @@ print(f'[{time.ctime()}][main/Info] module colorama inited')
 print(f'[{time.ctime()}][main/Info] modules initlazed')
 
 Ui_MainWindow,_ = loadUiType('downloader.ui')
+Ui_MainWindow2,_ = loadUiType('about.ui')
+class window2(QtWidgets.QMainWindow,Ui_MainWindow2):
+    def __init__(self):
+        super(window2,self).__init__()
+        self.setupUi(self)
+        self.pushButton.clicked.connect(self.close)
+
+
+
+
 class window(QtWidgets.QMainWindow,Ui_MainWindow):
+    signal = pyqtSignal()
     def __init__(self):
         print(f'[{time.ctime()}][main/Info] loading')
         super(window,self).__init__()
@@ -24,6 +35,8 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.te = ''
         self.progressBar.setValue(0)
         self.pushButton_2.clicked.connect(self.fwa)
+        self.pushButton_3.clicked.connect(self.about)
+
 
         self.setWindowIcon(QIcon('icon.bmp'))
         print(f'[{time.ctime()}][main/Info] icon loaded')
@@ -43,6 +56,10 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.timer.timeout.connect(self.write)
         self.timer.start(500)
         print(f'[{time.ctime()}][main/Info] timer initlazing sucsess')
+    def about(self):
+        self.signal.emit()
+    def opencmd(self):
+        os.system('cmd')
     def fwa(self):
         self.print()
         self.close()
@@ -191,6 +208,8 @@ print(f'[{time.ctime()}][main/Info] backend library:PyQt5 version {PYQT_VERSION_
 app = QtWidgets.QApplication(sys.argv)
 window = window()
 window.show()
+window2=window2()
+window.signal.connect(window2.show)
 sys.exit(app.exec_())
 
 
